#!/bin/sh
VERSION=1.0.0
##command with path
#set -x

check_version()
{
	echo "Check system version."
	echo "system version:$SYSTEM_VER"
	if [ $? -ne 0 ]
        then
		echo "check version error..."
		return 1
        fi
	return 2
}

xtar_packet()
{
	echo "compress pack.bin"
	cd $compress_path
	tar -xf pack.bin
	if [ $? -ne 0 ]
        then    
                rm -fr pack.*
		return 1
        fi
	rm -fr pack.*
	return 0
}

md5sum_check()
{	
	#md5 check
	$MD5SUM -c pack.md5
	if [ $? -ne 0 ]
	then
		echo "md5 check error."
		#remove pack.bin
		rm -fr pack.*
		return 3
	else
		echo "md5 check ok."
		return 0
	fi
	
	return 0
}

get_macaddr()
{
	ADAPTER=$1
	ADDR=$(cat /sys/class/net/${ADAPTER}/address)
	echo $ADDR
}

set_ipaddr()
{
	IP=$1
	ROUTE=$2
	DNS=$3

	VAR='./dhcpcd.conf'
cat > ${VAR} <<- EOF
hostname
clientid
persistent
option rapid_commit
option interface_mtu
require dhcp_server_identifier
slaac private

interface eth0
static ip_address=${IP}
static routers=${ROUTE}
static domain_name_servers=${DNS}

EOF
	sudo cp -fr ${VAR} /etc/
}

rtmp_start()
{
	RTMPSRV=$1

	libcamera-vid --inline --nopreview -t 0 --width 640 --height 480 --framerate 15 --codec h264 -o - | ffmpeg -f lavfi -i anullsrc=channel_layout=stereo:sample_rate=44100 -thread_queue_size 1024 -use_wallclock_as_timestamps 1 -i pipe:0 -c:v copy -c:a aac -preset fast -strict experimental -f flv rtmp://${RTMPSRV}
}

rtmp_stop()
{
	killall ffmpeg
}

bootloader()
{
	##start network detection
	cd /home/andy/csboot/
	./csboots > /tmp/booter.log 2>&1
	name=$(cat /etc/fwissue)
	if [ "$name" = "control" ]
	then
		echo "server board"
		#move2tmpfs
		cp -fr /home/andy/etcd-v3.5.7 /tmp/
		mkdir /tmp/mc-service
		cp -fr /home/andy/mc-service/server /tmp/mc-service
		cp -fr /home/andy/mc-service/admin /tmp/mc-service

		export PATH=$PATH:/tmp/etcd-v3.5.7/
		cd /tmp/etcd-v3.5.7
		nohup etcd --name mc-service --listen-client-urls http://0.0.0.0:2379 --advertise-client-urls http://0.0.0.0:2379 --listen-peer-urls http://127.0.0.1:2380 --initial-advertise-peer-urls http://127.0.0.1:2380 --initial-cluster-token etcd-cluster-1 --initial-cluster-state new --enable-pprof --logger=zap --log-outputs=stderr &

		cd /tmp/mc-service; nohup ./server --conf=/home/andy/mc-service/configs --data=/home/andy/mc-service &
	else
		echo "camera board"
		mkdir /tmp/mc-client
		cp -fr /home/andy/mc-client/server /tmp/mc-client
		cd /tmp/mc-client && ./server --conf=/home/andy/mc-client/configs --resource=./resource &
	fi

	##ntpd check
	sudo ntpd -s -d
}

case $1 in
	version)
		echo "$VERSION"
		;;
	setip)
		set_ipaddr $2 $3 $4
		;;
 	xtar)
		echo "check and compress upgrade packet......"
		md5sum_check
		ret=$?
		if [ $ret -ne 0 ]
                then
                        echo "$packet_name md5sum check error..."
                        exit $ret
                fi
		xtar_packet
		if [ $? -ne 0 ]
                then
                        echo "$packet_name compress error..."
                        exit 4
                fi
		echo 1 > /etc/upgrade.status
		;;
	start)
		case $2 in
		rtmp)
			echo "start rtmp..."
			rtmp_start $3
		;;
		booter)
			echo "start booter"
			bootloader
		;;
		esac
	;;
	stop)
		case $2 in
		rtmp)
			echo "stop rtmp..."
			killall ffmpeg
		;;
		esac
	;;
	macaddr)
		get_macaddr $2
		;;
	reboot)
		sudo reboot
		;;
	*)
		echo "check input command......"
		;;
esac

exit 0

